#! /bin/sh

# export the package to the desktop
# $1 should be the target
# $2 should be the version, ie: 0.5

mkdir /scratchbox/users/anthony/home/anthony/package/

mkdir /scratchbox/users/anthony/home/anthony/package/$1-$2/
echo 'Made Directory /scratchbox/users/anthony/home/anthony/'$1'/'

mkdir /scratchbox/users/anthony/home/anthony/package/$1-$2/src/
echo 'Made Directory /scratchbox/users/anthony/home/anthony/'$1'/src/'

cp * /scratchbox/users/anthony/home/anthony/package/$1-$2/src/
echo 'Copied source files into /scratchbox/users/anthony/home/anthony/'$1'/src/'

mv /scratchbox/users/anthony/home/anthony/package/$1-$2/src/maemo.pro /scratchbox/users/anthony/home/anthony/package/$1-$2/$1.pro
echo 'Moved maemo.pro file to the toplevel as '$1'.pro'

mv /scratchbox/users/anthony/home/anthony/package/$1-$2/src/$1.pro /scratchbox/users/anthony/home/anthony/package/$1-$2/src/src.pro
echo 'Renamed '$1'.pro as src.pro'

mkdir /scratchbox/users/anthony/home/anthony/package/$1-$2/data/
mkdir /scratchbox/users/anthony/home/anthony/package/$1-$2/data/64x64/
echo 'Created the data directory'

mv /scratchbox/users/anthony/home/anthony/package/$1-$2/src/$1.png /scratchbox/users/anthony/home/anthony/package/$1-$2/data/64x64/
mv /scratchbox/users/anthony/home/anthony/package/$1-$2/src/$1.desktop /scratchbox/users/anthony/home/anthony/package/$1-$2/data/
echo 'Moved image and desktop file to the data directory'



echo
echo 'Whats left:'
echo '1. Check the version in the .desktop file'
echo '2. Folder should be in /scratchbox/users/anthony/home/anthony/'
echo '3. cd to that top level directory'
echo '4. export DEBFULLNAME="Anthony Naddeo"'
echo '5. dh_make --createorig --single -e anthony.naddeo@gmail.com -c gpl'
echo '6. use dch to edit the changelog in the full bash terminal, not scratchbox'
echo '6. edit the control, changelog and rules files in the debian directory'
echo '7. remove the orig.tar.gz from the directory or the debian folder wont get built into the archive!'
echo '8. dpkg-buildpackage -i -rfakeroot -kanthony.naddeo@gmail.com -D'

#echo $1-$2

